==> wicket-jquery-ui-core-6.18.0-sources.jar: com/googlecode/wicket/jquery/core/panel/LabelPanel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.jquery.core.panel;

import org.apache.wicket.markup.html.WebMarkupContainer;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.IModel;

/**
 * Provides a {@link Panel} that just contains a {@link Label}<br/>
 * This is used, for instance, when a {@link WebMarkupContainer} is expected but just a Label is needed.
 *
 * @author Sebastien Briquet - sebfz1
 * @since 1.2.3
 * @since 6.0.1
 */
public class LabelPanel extends Panel
{
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 *
	 * @param id the markup id
	 * @param model the label's model
	 */
	public LabelPanel(String id, IModel<?> model)
	{
		super(id, model);
	}

	@Override
	protected void onInitialize()
	{
		super.onInitialize();

		this.add(this.newLabel("label", this.getDefaultModel()).setRenderBodyOnly(true));
	}

	// Factories //

	/**
	 * Gets a new Label
	 * 
	 * @param id the markup id
	 * @param model the {@link IModel}
	 * @return the new {@link Label}
	 */
	protected Label newLabel(String id, IModel<?> model)
	{
		return new Label(id, model);
	}
}

==> wicket-jquery-ui-core-8.6.0-sources.jar: com/googlecode/wicket/jquery/core/panel/LabelPanel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.jquery.core.panel;

import org.apache.wicket.markup.html.WebMarkupContainer;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.IModel;

/**
 * Provides a {@link Panel} that just contains a {@link Label}<br>
 * This is used, for instance, when a {@link WebMarkupContainer} is expected but just a Label is needed.
 *
 * @author Sebastien Briquet - sebfz1
 * @since 1.2.3
 * @since 6.0.1
 */
public class LabelPanel extends Panel
{
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor
	 *
	 * @param id the markup id
	 * @param model the label's model
	 */
	public LabelPanel(String id, IModel<?> model)
	{
		super(id, model);
	}

	@Override
	protected void onInitialize()
	{
		super.onInitialize();

		this.add(this.newLabel("label", this.getDefaultModel()).setRenderBodyOnly(true));
	}

	// Factories //

	/**
	 * Gets a new Label
	 * 
	 * @param id the markup id
	 * @param model the {@link IModel}
	 * @return the new {@link Label}
	 */
	protected Label newLabel(String id, IModel<?> model)
	{
		Label label = new Label(id, model);
		label.setEscapeModelStrings(this.getEscapeModelStrings());

		return label;
	}
}
